library(foreign)
library(memisc)
library(lavaan)
library(car)
library(stats)
library(xtable)
library(MASS)
library(stargazer)
library(e1071)
library(psych)
library(sjPlot)
library(mediation)
library(effects)
library(ggplot2)
library(reshape2)
library(aod)
library(visreg)

data <- read.csv(".../study1_final.csv") 


#################################################
#################Variables#####################
#################################################

#Condition
data$condition <- as.factor(data$condition)
levels(data$condition)=c("Control", "Ebola")
table(data$condition)

#Xenophobia
summary(data$Q22_1)
data$rQ22_1 <- (6-data$Q22_1)
summary(data$rQ22_1)
summary(data$Q22_5)
data$rQ22_5 <- (6-data$Q22_5)
summary(data$rQ22_5)
summary(data$Q22_6)
data$rQ22_6 <- (6-data$Q22_6)
summary(data$rQ22_6)
summary(data$Q22_7)
data$rQ22_7 <- (6-data$Q22_7)
summary(data$rQ22_7)
summary(data$Q22_9)
data$rQ22_9 <- (6-data$Q22_9)
summary(data$rQ22_9)
summary(data$Q22_10)
data$rQ22_10 <- (6-data$Q22_10)
summary(data$rQ22_10)

data$Xeno <- (rowMeans(data[,c("rQ22_1",  "Q22_2",  "Q22_3",	"Q22_4",	"rQ22_5",	
                               "rQ22_6",	"rQ22_7",	
                               "Q22_8",	"rQ22_9",	"rQ22_10",	"Q22_11",	"Q22_12",	
                               "Q22_13")], na.rm=T))
summary(data$Xeno)
#8, 11, 12, and 13 are angry, disgusted, fearful, and anxious, respectively

#Disease Anxiety
data$Disease <- (rowMeans(data[,c("Q6_1",  "Q6_2",  "Q6_3",  "Q6_4",	"Q6_5",	
                                  "Q6_6")], na.rm=T))
summary(data$Disease)
data$Disease_c <- data$Disease - mean(data$Disease, na.rm=T)
summary(data$Disease_c)

#Wilson-Patterson Ideology
summary(data$Q24_2)
data$rQ24_2 <- (6-data$Q24_2)
summary(data$rQ24_2)
summary(data$Q24_3)
data$rQ24_3 <- (6-data$Q24_3)
summary(data$rQ24_3)
summary(data$Q24_4)
data$rQ24_4 <- (6-data$Q24_4)
summary(data$rQ24_4)
summary(data$Q24_6)
data$rQ24_6 <- (6-data$Q24_6)
summary(data$rQ24_6)
summary(data$Q24_8)
data$rQ24_8 <- (6-data$Q24_8)
summary(data$rQ24_8)
summary(data$Q24_9)
data$rQ24_9 <- (6-data$Q24_9)
summary(data$rQ24_9)
summary(data$Q24_10)
data$rQ24_10 <- (6-data$Q24_10)
summary(data$rQ24_10)
summary(data$Q24_11)
data$rQ24_11 <- (6-data$Q24_11)
summary(data$rQ24_11)
summary(data$Q24_14)
data$rQ24_14 <- (6-data$Q24_14)
summary(data$rQ24_14)
summary(data$Q24_18)
data$rQ24_18 <- (6-data$Q24_18)
summary(data$rQ24_18)
summary(data$Q24_19)
data$rQ24_19 <- (6-data$Q24_19)
summary(data$rQ24_19)
#Not using Q24_21
data$WP <- (rowMeans(data[,c("Q24_1", "rQ24_2", "rQ24_3", "rQ24_4", "Q24_5", "rQ24_6", "Q24_7", 
                             "rQ24_8", "rQ24_9", "rQ24_10", "rQ24_11", "Q24_12", "Q24_13", "rQ24_14", "Q24_15", "Q24_16", 
                             "Q24_17", "rQ24_18", "rQ24_19", "Q24_20", "Q24_22", "Q24_23", "Q24_24")], na.rm=T))
summary(data$WP)

#Demographics
data$male[Q26 == 1] <- 1
data$male[Q26 == 2] <- 0
table(data$male)

data$age <- (2014 - data$Q40)
summary(data$age)

summary(data$Q42_5)
data$NonWhite[Q42_1 == 1] <- 1
data$NonWhite[Q42_2 == 1] <- 1
data$NonWhite[Q42_3 == 1] <- 1
data$NonWhite[Q42_4 == 1] <- 1
data$NonWhite[Q42_5 == 1] <- 0
data$NonWhite[Q42_1 == 1] <- 1
summary(data$NonWhite)
table(data$NonWhite)

summary(data$Q34)
data$Educ <- data$Q34
summary(data$Educ)

data$PartyID[Q28 == 1 & Q30 == 1] <- 1
data$PartyID[Q28 == 1 & Q30 == 2] <- 2
data$PartyID[Q28 == 3 & Q43 == 2] <- 3
data$PartyID[Q28 == 4 & Q43 == 2] <- 3
data$PartyID[Q28 == 3 & Q43 == 3] <- 4
data$PartyID[Q28 == 4 & Q43 == 3] <- 4
data$PartyID[Q28 == 3 & Q43 == 1] <- 5
data$PartyID[Q28 == 4 & Q43 == 1] <- 5
data$PartyID[Q28 == 2 & Q32 == 2] <- 6
data$PartyID[Q28 == 2 & Q32 == 1] <- 7
summary(data$PartyID)

#Ebola questions/primes
summary(data$Q1)
data$ebola1 <- data$Q1
summary(data$ebola1)
summary(data$Q2)
data$ebola2 <- data$Q2
summary(data$ebola2)
summary(data$Q3_1)
data$ebola3 <- data$Q3_1
summary(data$ebola3)
summary(data$Q3_2)
data$ebola4 <- data$Q3_2
summary(data$ebola4)

#Aid Support
summary(data$Q5_1)
data$ForAid1 <- data$Q5_1
summary(data$ForAid1)
summary(data$Q5_2)
data$ForAid2 <- data$Q5_2
summary(data$ForAid2)
summary(data$Q5_3)
data$ForAid3 <- data$Q5_3
summary(data$ForAid3)

#Self-report ideology
summary(data$Q36.1)
table(data$Q36.1)
data$Ideology <- data$Q36.1
summary(data$Ideology)

#threatened by ebola?
data$ebola_threat <- data$Q1
summary(data$ebola_threat)
data$ebola_threat <- ifelse(is.na(data$ebola_threat), data$Q18, data$ebola_threat)
summary(data$ebola_threat)

#Centering for interactions
data$Xeno_c <- data$Xeno - mean(data$Xeno)
summary(data$Xeno_c)

#Looking at level of threat from prime
data$ebola_threat_c <- data$ebola_threat - mean(data$ebola_threat)
summary(data$ebola_threat_c)

#Condition
data$Disease_c <- data$Disease - mean(data$Disease)
summary(data$Disease_c)
attach(data)


#####Main Analyses#####

aov1 <- aov(ForAid1 ~ condition, data)
summary(aov1)
aov1$coe
table1 <- stats:::aggregate.formula(ForAid1 ~ condition, data, mean)
table1 <- xtable(table1)
print(table1)

aov2 <- aov(ForAid2 ~ condition, data)
summary(aov2)
table2 <- stats:::aggregate.formula(ForAid2 ~ condition, data, mean)
table2
table2 <- xtable(table2)
print(table2)

aov6 <- aov(data$Xeno ~ data$condition, data)
aov6
summary(aov6)
aggregate(data$Xeno, by=list(data$condition), FUN=mean, na.rm=T)
aggregate(data$Xeno, by=list(data$condition), FUN=sd, na.rm=T)

lm7 <- polr(as.factor(ForAid1) ~ condition + Disease + male + NonWhite + age + Educ)
summary(lm7)
ctable <- coef(summary(lm7))
pv <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2
ctable <- cbind(ctable, "p value" = pv)
ctable
ci <- confint(lm7)
ci
exp(coef(lm7))
exp(cbind(OR = coef(lm7), ci))
OR.vector <- exp(lm7$coef)
OR.vector
cie <- exp(ci)
cie

lm7b <- polr(as.factor(ForAid2) ~ condition + Disease + male + NonWhite + age + Educ)
summary(lm7b)
ctable2 <- coef(summary(lm7b))
pv2 <- pnorm(abs(ctable2[, "t value"]), lower.tail = FALSE) * 2
ctable2 <- cbind(ctable2, "p value" = pv2)
ctable2
ci2 <- confint(lm7b)
ci2
exp(coef(lm7b))
exp(cbind(OR = coef(lm7b), ci2))
OR.vector2 <- exp(lm7b$coef)
OR.vector2
cie2 <- exp(ci2)
cie2


#####Analyses with(out) attention fail people#####

table(Q47)

data1 <- subset(data, Q47==4)
attach(data1)

#####***ANOVAS#####
aov1 <- aov(data1$ForAid1 ~ data1$condition, data1)
aov1
summary(aov1)
aggregate(data1$ForAid1, by=list(data1$condition), FUN=mean, na.rm=T)
aggregate(data1$ForAid1, by=list(data1$condition), FUN=sd, na.rm=T)

aov2 <- aov(data1$ForAid2 ~ data1$condition, data1)
aov2
summary(aov2)
aggregate(data1$ForAid2, by=list(data1$condition), FUN=mean, na.rm=T)
aggregate(data1$ForAid2, by=list(data1$condition), FUN=sd, na.rm=T)

aov6 <- aov(data1$Xeno ~ data1$condition, data1)
aov6
summary(aov6)
aggregate(data1$Xeno, by=list(data1$condition), FUN=mean, na.rm=T)
aggregate(data1$Xeno, by=list(data1$condition), FUN=sd, na.rm=T)

#No differences in results

#####***Ordered Logits#####

lm7 <- polr(as.factor(ForAid1) ~ condition + Disease + male + Ideology + NonWhite + age + Educ)
summary(lm7)
ctable <- coef(summary(lm7))
pv <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2
ctable <- cbind(ctable, "p value" = pv)
ctable
ci <- confint(lm7)
ci
exp(coef(lm7))
exp(cbind(OR = coef(lm7), ci))
OR.vector <- exp(lm7$coef)
OR.vector
cie <- exp(ci)
cie

lm7b <- polr(as.factor(ForAid2) ~ condition + male + Disease + Ideology + NonWhite + age + Educ)
summary(lm7b)
ctable2 <- coef(summary(lm7b))
pv2 <- pnorm(abs(ctable2[, "t value"]), lower.tail = FALSE) * 2
ctable2 <- cbind(ctable2, "p value" = pv2)
ctable2
ci2 <- confint(lm7b)
ci2
exp(coef(lm7b))
exp(cbind(OR = coef(lm7b), ci2))
OR.vector2 <- exp(lm7b$coef)
OR.vector2
cie2 <- exp(ci2)
cie2

lm8a <- polr(as.factor(ForAid1) ~ condition + Disease + Xeno + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8a)
ctable3a <- coef(summary(lm8a))
pv3a <- pnorm(abs(ctable3a[, "t value"]), lower.tail = FALSE) * 2
ctable3a <- cbind(ctable3a, "p value" = pv3a)
ctable3a
ci3a <- confint(lm8a)
ci3a
exp(coef(lm8a))
exp(cbind(OR = coef(lm8a), ci3a))
OR.vector3a <- exp(lm8a$coef)
OR.vector3a
ci3ea <- exp(ci3a)
ci3ea 

lm8b <- polr(as.factor(ForAid2) ~ condition + Disease + Xeno + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8b)
ctable3b <- coef(summary(lm8b))
pv3b <- pnorm(abs(ctable3b[, "t value"]), lower.tail = FALSE) * 2
ctable3b <- cbind(ctable3b, "p value" = pv3b)
ctable3b
ci3b <- confint(lm8b)
ci3b
exp(coef(lm8b))
exp(cbind(OR = coef(lm8b), ci3b))
OR.vector3b <- exp(lm8b$coef)
OR.vector3b
ci3eb <- exp(ci3b)
ci3eb

#No differences in results


#####Analyses without nonwhites#####

table(data$NonWhite) #19.8% nonwhite 
table(data$Q42_3) #17 of the nonwhite participats are Black
data2 <- subset(data, NonWhite==0)
attach(data2)

#####***ANOVAS#####
aov1 <- aov(data2$ForAid1 ~ data2$condition, data2)
aov1
summary(aov1)
aggregate(data2$ForAid1, by=list(data2$condition), FUN=mean, na.rm=T)
aggregate(data2$ForAid1, by=list(data2$condition), FUN=sd, na.rm=T)

aov2 <- aov(data2$ForAid2 ~ data2$condition, data2)
aov2
summary(aov2)
aggregate(data2$ForAid2, by=list(data2$condition), FUN=mean, na.rm=T)
aggregate(data2$ForAid2, by=list(data2$condition), FUN=sd, na.rm=T)

aov6 <- aov(data2$Xeno ~ data2$condition, data2)
aov6
summary(aov6)
aggregate(data2$Xeno, by=list(data2$condition), FUN=mean, na.rm=T)
aggregate(data2$Xeno, by=list(data2$condition), FUN=sd, na.rm=T)

#No differences in results

#####***Ordered Logits#####

lm7 <- polr(as.factor(ForAid1) ~ condition + Disease + male + Ideology + NonWhite + age + Educ)
summary(lm7)
ctable <- coef(summary(lm7))
pv <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2
ctable <- cbind(ctable, "p value" = pv)
ctable
ci <- confint(lm7)
ci
exp(coef(lm7))
exp(cbind(OR = coef(lm7), ci))
OR.vector <- exp(lm7$coef)
OR.vector
cie <- exp(ci)
cie

lm7b <- polr(as.factor(ForAid2) ~ condition + male + Disease + Ideology + NonWhite + age + Educ)
summary(lm7b)
ctable2 <- coef(summary(lm7b))
pv2 <- pnorm(abs(ctable2[, "t value"]), lower.tail = FALSE) * 2
ctable2 <- cbind(ctable2, "p value" = pv2)
ctable2
ci2 <- confint(lm7b)
ci2
exp(coef(lm7b))
exp(cbind(OR = coef(lm7b), ci2))
OR.vector2 <- exp(lm7b$coef)
OR.vector2
cie2 <- exp(ci2)
cie2

lm8a <- polr(as.factor(ForAid1) ~ condition + Disease + Xeno + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8a)
ctable3a <- coef(summary(lm8a))
pv3a <- pnorm(abs(ctable3a[, "t value"]), lower.tail = FALSE) * 2
ctable3a <- cbind(ctable3a, "p value" = pv3a)
ctable3a
ci3a <- confint(lm8a)
ci3a
exp(coef(lm8a))
exp(cbind(OR = coef(lm8a), ci3a))
OR.vector3a <- exp(lm8a$coef)
OR.vector3a
ci3ea <- exp(ci3a)
ci3ea 

lm8b <- polr(as.factor(ForAid2) ~ condition + Disease + Xeno + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8b)
ctable3b <- coef(summary(lm8b))
pv3b <- pnorm(abs(ctable3b[, "t value"]), lower.tail = FALSE) * 2
ctable3b <- cbind(ctable3b, "p value" = pv3b)
ctable3b
ci3b <- confint(lm8b)
ci3b
exp(coef(lm8b))
exp(cbind(OR = coef(lm8b), ci3b))
OR.vector3b <- exp(lm8b$coef)
OR.vector3b
ci3eb <- exp(ci3b)
ci3eb

#No differences in results

#####Analyses with race interactions#####

attach(data)

lm7 <- polr(as.factor(ForAid1) ~ condition + Disease*NonWhite + male + Ideology + age + Educ)
summary(lm7)
ctable <- coef(summary(lm7))
pv <- pnorm(abs(ctable[, "t value"]), lower.tail = FALSE) * 2
ctable <- cbind(ctable, "p value" = pv)
ctable
ci <- confint(lm7)
ci
exp(coef(lm7))
exp(cbind(OR = coef(lm7), ci))
OR.vector <- exp(lm7$coef)
OR.vector
cie <- exp(ci)
cie #no interactions

lm7b <- polr(as.factor(ForAid2) ~ condition + male + Disease*NonWhite + Ideology + age + Educ)
summary(lm7b)
ctable2 <- coef(summary(lm7b))
pv2 <- pnorm(abs(ctable2[, "t value"]), lower.tail = FALSE) * 2
ctable2 <- cbind(ctable2, "p value" = pv2)
ctable2
ci2 <- confint(lm7b)
ci2
exp(coef(lm7b))
exp(cbind(OR = coef(lm7b), ci2))
OR.vector2 <- exp(lm7b$coef)
OR.vector2
cie2 <- exp(ci2)
cie2 #no interactions

lm8a <- polr(as.factor(ForAid1) ~ condition*NonWhite*Xeno + Disease + Ideology + 
               male + age + Educ)
summary(lm8a)
ctable3a <- coef(summary(lm8a))
pv3a <- pnorm(abs(ctable3a[, "t value"]), lower.tail = FALSE) * 2
ctable3a <- cbind(ctable3a, "p value" = pv3a)
ctable3a
ci3a <- confint(lm8a)
ci3a
exp(coef(lm8a))
exp(cbind(OR = coef(lm8a), ci3a))
OR.vector3a <- exp(lm8a$coef)
OR.vector3a
ci3ea <- exp(ci3a)
ci3ea  #no interactions

lm8b <- polr(as.factor(ForAid2) ~ condition + Disease*NonWhite*Xeno + Ideology + 
               male + age + Educ)
summary(lm8b)
ctable3b <- coef(summary(lm8b))
pv3b <- pnorm(abs(ctable3b[, "t value"]), lower.tail = FALSE) * 2
ctable3b <- cbind(ctable3b, "p value" = pv3b)
ctable3b
ci3b <- confint(lm8b)
ci3b
exp(coef(lm8b))
exp(cbind(OR = coef(lm8b), ci3b))
OR.vector3b <- exp(lm8b$coef)
OR.vector3b
ci3eb <- exp(ci3b)
ci3eb #no interactions



#####Moderation#####
table(condition)
condition2 <- relevel(condition, "Ebola")
lm8a <- polr(as.factor(ForAid1) ~ condition*Xeno + Disease + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8a)
plot(effect("condition*Xeno", lm8a)) #plotted using lm
ctable3a <- coef(summary(lm8a))
pv3a <- pnorm(abs(ctable3a[, "t value"]), lower.tail = FALSE) * 2
ctable3a <- cbind(ctable3a, "p value" = pv3a)
ctable3a
ci3a <- confint(lm8a)
ci3a
exp(coef(lm8a))
exp(cbind(OR = coef(lm8a), ci3a))
OR.vector3a <- exp(lm8a$coef)
OR.vector3a
ci3ea <- exp(ci3a)
ci3ea #interaction opposite of what BIS would suggest (for both condition and Disease Anxiety)

lm8b <- polr(as.factor(ForAid2) ~ condition*Xeno + Disease + Ideology + 
               male + NonWhite + age + Educ)
summary(lm8b)
plot(effect("condition*Xeno", lm8b)) #plotted using lm
ctable3b <- coef(summary(lm8b))
pv3b <- pnorm(abs(ctable3b[, "t value"]), lower.tail = FALSE) * 2
ctable3b <- cbind(ctable3b, "p value" = pv3b)
ctable3b
ci3b <- confint(lm8b)
ci3b
exp(coef(lm8b))
exp(cbind(OR = coef(lm8b), ci3b))
OR.vector3b <- exp(lm8b$coef)
OR.vector3b
ci3eb <- exp(ci3b)
ci3eb #interaction opposite of what BIS would suggest (only for condition)


