library(foreign)
library(memisc)
library(psych)
library(lavaan)
library(car)
library(stats)
library(xtable)
library(MASS)
library(stargazer)
library(e1071)
library(sjPlot)
library(contrast)
library(mediation)
library(factorplot)
library(lsmeans)
library(qvcalc)
library(lattice)
library(effects)

data <- read.csv(".../study2_final.csv") 

attach(data)
##################Descriptives###############

#Ideo and ideo by condition
hist(ideo)
summary(ideo)
aov1 <- aov(ideo ~ condition, data)
summary(aov1)
aov1$coe
table1 <- stats:::aggregate.formula(ideo ~ condition, data, mean)
table1 
#no sig diff in ideo across conditions

#Support
hist(Q38)
summary(Q38)
table1 <- stats:::aggregate.formula(Q38 ~ condition, data, mean)
table1 

#sex
table(male)
table1 <- stats:::aggregate.formula(male ~ condition, data, mean)
table1 

#age
hist(age)
table1 <- stats:::aggregate.formula(age ~ condition, data, mean)
table1

#white
table(white)
table1 <- stats:::aggregate.formula(white ~ condition, data, mean)
table1

#south
table(south)
table1 <- stats:::aggregate.formula(south ~ condition, data, mean)
table1

#born again
table(bornagain)
table1 <- stats:::aggregate.formula(bornagain ~ condition, data, mean)
table1

#religiosity
hist(AS)
table1 <- stats:::aggregate.formula(AS ~ condition, data, median)
table1

#pid
hist(pid)
table1 <- stats:::aggregate.formula(pid ~ condition, data, mean)
table1

#Educ
table(Q32)


######################ORDERED LOGITS####################

polr1 <- polr(as.factor(Q38) ~ disease + africa + govt + refuge + ideo + male + age + white + south 
           + bornagain, data)
summary(polr1)
Anova(polr1)
ctablea <- coef(summary(polr1))
pva <- pnorm(abs(ctablea[, "t value"]), lower.tail = FALSE) * 2
ctablea <- cbind(ctablea, "p value" = pva)
ctablea
cia <- confint(polr1)
cia
exp(coef(polr1))
exp(cbind(OR = coef(polr1), cia))
OR.vectora <- exp(polr1$coef)
OR.vectora
ciae <- exp(cia)
ciae

data$mon <- ifelse(data$refuge==1, 0, 1)
table(data$refuge)
table(data$mon)
attach(data)

polr2 <- polr(as.factor(Q38) ~ disease*africa*govt*mon + ideo + male + age + white + south 
              + bornagain, data)
summary(polr2)
Anova(polr2)
ctablea2 <- coef(summary(polr2))
pva2 <- pnorm(abs(ctablea2[, "t value"]), lower.tail = FALSE) * 2
ctablea2 <- cbind(ctablea2, "p value" = pva2)
ctablea2
cia2 <- confint(polr2)
cia2
exp(coef(polr2))
exp(cbind(OR = coef(polr2), cia2))
OR.vectora2 <- exp(polr2$coef)
OR.vectora2
cia2e <- exp(cia2)
cia2e

######Just main effects model 

mod1 <- polr(as.factor(Q38) ~ cond2 + ideo + male + age + white + south 
             + bornagain, data=data)
summary(mod1)
lsm1 <- lsmeans(mod1, "cond2")
summary(lsm1, adjust="bon", level=.95)
pairs(lsm1, adjust="bon")

qv1 <- qvcalc(mod1, "cond2")
summary(qv1)

plot(qv1, type="p", xlab="Condition", ylab="Estimate", 
     col=ifelse(cond2=="Dis_Euro_Mon_Char", "red","black"), 
     main="Effects of Condition based on Quasi Standard Errors", 
     #levelNames=c(1:16), 
     intervalWidth=2#, pch=ifelse(cond2==3 | cond2=4,15,16)
     #cex=ifelse(cond2==1,2,1)
     )










